==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/SubnetResourceSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.SubnetResourceSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Defines the virtual network subnets resource settings.
 * @property addressPrefix Gets or sets address prefix for the subnet.
 * @property name Gets or sets the Subnet name.
 * @property networkSecurityGroup Defines reference to NSG.
 */
public data class SubnetResourceSettingsArgs(
    public val addressPrefix: Output<String>? = null,
    public val name: Output<String>? = null,
    public val networkSecurityGroup: Output<NsgReferenceArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.SubnetResourceSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.SubnetResourceSettingsArgs =
        com.pulumi.azurenative.migrate.inputs.SubnetResourceSettingsArgs.builder()
            .addressPrefix(addressPrefix?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .networkSecurityGroup(
                networkSecurityGroup?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [SubnetResourceSettingsArgs].
 */
@PulumiTagMarker
public class SubnetResourceSettingsArgsBuilder internal constructor() {
    private var addressPrefix: Output<String>? = null

    private var name: Output<String>? = null

    private var networkSecurityGroup: Output<NsgReferenceArgs>? = null

    /**
     * @param value Gets or sets address prefix for the subnet.
     */
    @JvmName("plbswdicppafvruu")
    public suspend fun addressPrefix(`value`: Output<String>) {
        this.addressPrefix = value
    }

    /**
     * @param value Gets or sets the Subnet name.
     */
    @JvmName("pynmxksfhiefyerg")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Defines reference to NSG.
     */
    @JvmName("almpenwguitafkxf")
    public suspend fun networkSecurityGroup(`value`: Output<NsgReferenceArgs>) {
        this.networkSecurityGroup = value
    }

    /**
     * @param value Gets or sets address prefix for the subnet.
     */
    @JvmName("fhvudewkwbjaaybx")
    public suspend fun addressPrefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.addressPrefix = mapped
    }

    /**
     * @param value Gets or sets the Subnet name.
     */
    @JvmName("rrcuhhkljucrsalh")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Defines reference to NSG.
     */
    @JvmName("udlnbtgncbdidkro")
    public suspend fun networkSecurityGroup(`value`: NsgReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkSecurityGroup = mapped
    }

    /**
     * @param argument Defines reference to NSG.
     */
    @JvmName("hhhpqbjkyaxvxrlw")
    public suspend fun networkSecurityGroup(argument: suspend NsgReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = NsgReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.networkSecurityGroup = mapped
    }

    internal fun build(): SubnetResourceSettingsArgs = SubnetResourceSettingsArgs(
        addressPrefix = addressPrefix,
        name = name,
        networkSecurityGroup = networkSecurityGroup,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/SubnetResourceSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.SubnetResourceSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Defines the virtual network subnets resource settings.
 * @property addressPrefix Gets or sets address prefix for the subnet.
 * @property name Gets or sets the Subnet name.
 * @property networkSecurityGroup Defines reference to NSG.
 */
public data class SubnetResourceSettingsArgs(
    public val addressPrefix: Output<String>? = null,
    public val name: Output<String>? = null,
    public val networkSecurityGroup: Output<NsgReferenceArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.SubnetResourceSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.SubnetResourceSettingsArgs =
        com.pulumi.azurenative.migrate.inputs.SubnetResourceSettingsArgs.builder()
            .addressPrefix(addressPrefix?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .networkSecurityGroup(
                networkSecurityGroup?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [SubnetResourceSettingsArgs].
 */
@PulumiTagMarker
public class SubnetResourceSettingsArgsBuilder internal constructor() {
    private var addressPrefix: Output<String>? = null

    private var name: Output<String>? = null

    private var networkSecurityGroup: Output<NsgReferenceArgs>? = null

    /**
     * @param value Gets or sets address prefix for the subnet.
     */
    @JvmName("pwbyhnryuqeeevga")
    public suspend fun addressPrefix(`value`: Output<String>) {
        this.addressPrefix = value
    }

    /**
     * @param value Gets or sets the Subnet name.
     */
    @JvmName("owbgpgqvskwdkplw")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Defines reference to NSG.
     */
    @JvmName("jbngbqiekaohifdl")
    public suspend fun networkSecurityGroup(`value`: Output<NsgReferenceArgs>) {
        this.networkSecurityGroup = value
    }

    /**
     * @param value Gets or sets address prefix for the subnet.
     */
    @JvmName("blhfbegvsxcohcgr")
    public suspend fun addressPrefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.addressPrefix = mapped
    }

    /**
     * @param value Gets or sets the Subnet name.
     */
    @JvmName("eedehenvhamqrjsx")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Defines reference to NSG.
     */
    @JvmName("lmfsvkyxyxhsxpkf")
    public suspend fun networkSecurityGroup(`value`: NsgReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkSecurityGroup = mapped
    }

    /**
     * @param argument Defines reference to NSG.
     */
    @JvmName("mdiemjmtyufnmmbf")
    public suspend fun networkSecurityGroup(argument: suspend NsgReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = NsgReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.networkSecurityGroup = mapped
    }

    internal fun build(): SubnetResourceSettingsArgs = SubnetResourceSettingsArgs(
        addressPrefix = addressPrefix,
        name = name,
        networkSecurityGroup = networkSecurityGroup,
    )
}
